<template>
    <div class="device-status">
        <div class="content">
            <div
                class="box"
                style="--w: 200px; --n: 40; --t: 8px; --d: 3deg; --c: #177eff"
            >
                <div
                    ref="chartRef"
                    style="width: 200px; min-height: 200px"
                ></div>
            </div>
        </div>
        <div class="data-tag-container">
            <div class="data-item">
                <div class="left-border"></div>
                <div class="content-container">
                    <span>PM 2.5:</span>
                    <span>36.3ug/㎡</span>
                </div>
                <div class="right-border"></div>
            </div>
        </div>
    </div>
</template>
<script lang="ts" name="AirQuality" setup>
import * as echarts from 'echarts';
const chartRef = ref<Record<string, any>>({});
let myChart: any = null;

const handleOptions = (x = [], y = []) => {
    const chart: any = chartRef.value;
    if (chart) {
        myChart = echarts.init(chart);
        const options = {
            // grid: {
            //     top: '0%',
            //     left: '0%',
            //     right: '0%',
            //     bottom: '0%',
            //     containLabel: true,
            // },
            series: [
                {
                    type: 'gauge',
                    startAngle: -90,
                    endAngle: 270,
                    min: 0,
                    max: 100,
                    // splitNumber: 12,
                    // itemStyle: {
                    //   color: '#58D9F9',
                    //   shadowColor: 'rgba(0,138,255,0.45)',
                    //   shadowBlur: 10,
                    //   shadowOffsetX: 2,
                    //   shadowOffsetY: 2
                    // },
                    progress: {
                        show: true,
                        roundCap: true,
                        width: 9,
                        itemStyle: {
                            color: {
                                type: 'linear',
                                x: 0,
                                y: 0,
                                x2: 0,
                                y2: 1,
                                colorStops: [
                                    {
                                        offset: 0,
                                        color: '#15C646', // 0% 处的颜色
                                    },
                                    {
                                        offset: 1,
                                        color: 'white', // 100% 处的颜色
                                    },
                                ],
                                global: false, // 缺省为 false
                            },
                        },
                    },
                    pointer: {
                        show: false,
                    },
                    axisLine: {
                        roundCap: true,
                        lineStyle: {
                            width: 9,
                            color: [[1, '#E2F7E8']],
                            shadowColor: 'rgba(85, 255, 0, 1)',
                            opacity: 0.5,
                        },
                    },
                    axisTick: {
                        show: false,
                    },
                    splitLine: {
                        show: false,
                    },
                    axisLabel: {
                        show: false,
                    },
                    title: {
                        show: true,
                        offsetCenter: [0, '30%'],
                        color: '#828282',
                    },
                    detail: {
                        offsetCenter: [0, '0%'],
                        formatter: '{value}℃',
                    },
                    data: [
                        {
                            value: 33,
                            name: 'ug/㎡',
                        },
                    ],
                },
            ],
        };
        nextTick(() => {
            myChart.setOption(options);
            window.addEventListener('resize', function () {
                myChart.resize();
            });
        });
    }
};

onMounted(() => {
    handleOptions();
});
</script>
<style scoped lang="less">
@import url('./dashedLine.less');
.device-status {
    width: 100%;
    height: 100%;
    padding: 16px;
    background: #ffffff;
    box-shadow: 0px 2px 6px 0px #cccccc;
    border-radius: 4px 4px 4px 4px;
    .content {
        position: relative;
        width: 100%;
        padding: 24px;
        display: flex;
        align-items: center;
        justify-content: center;
        .flag {
            position: absolute;
            top: 175px;
            width: 180px;
            height: 50px;
            line-height: 40px;
            background: white;
            display: flex;
            justify-content: space-between;
        }
    }
    .data-tag-container {
        padding: 30px 0;
        display: flex;
        flex-direction: column;
        align-items: center;
        justify-content: center;
        .data-item {
            position: relative;
            width: 223px;
            padding-top: 6px;
            margin-bottom: 10px;
            .left-border {
                position: absolute;
                top: 0;
                left: 0;
                width: 5px;
                height: 44px;
                background: #8bbfff;
            }
            .content-container {
                width: 223px;
                height: 32px;
                background: #2988fe;
                display: flex;
                align-items: center;
                justify-content: center;
                color: white;
                span:nth-child(2) {
                    font-size: 20px;
                    padding-left: 10px;
                }
            }
            .right-border {
                position: absolute;
                top: 0;
                right: 0;
                width: 5px;
                height: 44px;
                background: #8bbfff;
            }
        }
    }
}
</style>
